==> flutter_tapjoy-1.2.0.tar.gz: android/src/main/java/com/anavrinapps/tapjoy/flutter_tapjoy/FlutterTapjoyPlugin.java <==
package com.anavrinapps.tapjoy.flutter_tapjoy;

import android.app.Activity;
import androidx.annotation.NonNull;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import com.tapjoy.TJPlacementListener;
import com.tapjoy.TJActionRequest;
import com.tapjoy.TJConnectListener;
import com.tapjoy.TJEarnedCurrencyListener;

import com.tapjoy.Tapjoy;
import com.tapjoy.TJError;
import com.tapjoy.TJPlacement;
import com.tapjoy.Tapjoy;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.Objects;

public class FlutterTapjoyPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static MethodChannel Channel;
    static Activity activity;
    TJPlacement placement;

    @Override
    public void onAttachedToEngine(@NonNull final FlutterPluginBinding flutterPluginBinding) {
        this.OnAttachedToEngine(flutterPluginBinding.getBinaryMessenger());
    }

    public static void registerWith(final Registrar registrar) {
        if (activity == null) activity = registrar.activity();
    }

    private void OnAttachedToEngine(final BinaryMessenger messenger) {
        if (FlutterTapjoyPlugin.Channel != null)
            return;
        FlutterTapjoyPlugin.Channel = new MethodChannel(messenger, "native");
        FlutterTapjoyPlugin.Channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull final Result result) {
        try {
            switch (call.method) {
                case "setEarnedCurrencyListener":
                    Tapjoy.setEarnedCurrencyListener(new TJEarnedCurrencyListener() {
                            @Override
                            public void onEarnedCurrency(String s, final int i) {
                                try {
                                    FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            Channel.invokeMethod("onEarnedCurrency", i);
                                        }
                                    });
                                } catch (final Exception e) {
                                    Log.e("Tapjoy", "Error " + e.toString());
                                }

                            }
                        });
                        break;
                        case "setDebugEnabled":
                            boolean isDebug;
                            if (call.argument("isDebug") != null) {
                                isDebug = call.argument("isDebug");
                            } else {
                                result.error("no_debug", "a null value for debug was provided", null);
                                return;
                            }
                            Tapjoy.setDebugEnabled(isDebug);
                            break;
                        case "setUserConsent":
                            String consent = null;
                            if (call.argument("consent") != null) {
                                consent = call.argument("consent");
                            } else {
                                result.error("no_consent", "a null consent string was provided", null);
                                return;
                            }
                            Tapjoy.setUserConsent(consent);
                            break;
                        case "connect":
                            String api_token = null;
                            if (call.argument("api_token") != null) {
                                api_token = call.argument("api_token");
                            } else {
                                result.error("no_api_token", "a null api token was provided", null);
                                return;
                            }
                            final Hashtable < String, Object > connectFlags = new Hashtable < > (); Tapjoy.connect(activity.getApplicationContext(), api_token, connectFlags, new TJConnectListener() {
                                @Override
                                public void onConnectSuccess() {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onConnectSuccess", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override
                                public void onConnectFailure() {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onConnectFailure", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }
                            });
                            break;
                        case "getPlacement":
                            String placementName = null;
                            if (call.argument("placementName") != null) {
                                placementName = call.argument("placementName");
                            } else {
                                result.error("no_placement_name", "a null placement name was provided", null);
                                return;
                            }
                            Tapjoy.setActivity(activity); placement = Tapjoy.getPlacement(placementName, new TJPlacementListener() {
                                @Override
                                public void onRequestSuccess(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onRequestSuccess", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }


                                @Override
                                public void onRequestFailure(final TJPlacement tjPlacement, final TJError tjError) {
                                    final String error = tjError.message;
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onRequestFailure", error);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override
                                public void onContentReady(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentReady", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }



                                @Override public void onContentShow(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentShow", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }

                                @Override public void onContentDismiss(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentDismiss", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override public void onRewardRequest(final TJPlacement tjPlacement, final TJActionRequest tjActionRequest, final String s, final int rew) {
                                    final int reward = rew;
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {

                                                Channel.invokeMethod("onReward", reward);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override public void onPurchaseRequest(final TJPlacement tjPlacement, final TJActionRequest tjActionRequest, final String s) {

                                }

                                @Override public void onClick(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onClick", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }
                            });
                            break;
                        case "requestContent":
                            if (Tapjoy.isConnected()) {
                                placement.requestContent();
                            } else {
                                Log.e("Tapjoy", "Tapjoy SDK must finish connecting before requesting content.");
                            }
                            break;
                        case "showContent":
                            if (placement.isContentReady()) {
                                placement.showContent();
                            } else {
                                Log.e("Tapjoy", "Tapjoy SDK content not downloaded.");
                            }

                            break;
                    }
                    result.success(Boolean.TRUE);
            } catch (final Exception e) {
                Log.e("Tapjoy", "Error " + e.toString());
            }
        }

        @Override
        public void onDetachedFromEngine(@NonNull final FlutterPluginBinding binding) {}

        @Override
        public void onAttachedToActivity(final ActivityPluginBinding binding) {
            FlutterTapjoyPlugin.activity = binding.getActivity();
        }

        @Override
        public void onDetachedFromActivityForConfigChanges() {

        }

        @Override
        public void onReattachedToActivityForConfigChanges(final ActivityPluginBinding binding) {
            FlutterTapjoyPlugin.activity = binding.getActivity();
        }

        @Override
        public void onDetachedFromActivity() {

        }

    }

==> flutter_tapjoy-1.2.1.tar.gz: android/src/main/java/com/anavrinapps/tapjoy/flutter_tapjoy/FlutterTapjoyPlugin.java <==
package com.anavrinapps.tapjoy.flutter_tapjoy;

import android.app.Activity;
import androidx.annotation.NonNull;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import com.tapjoy.TJPlacementListener;
import com.tapjoy.TJActionRequest;
import com.tapjoy.TJConnectListener;
import com.tapjoy.TJEarnedCurrencyListener;

import com.tapjoy.Tapjoy;
import com.tapjoy.TJError;
import com.tapjoy.TJPlacement;
import com.tapjoy.Tapjoy;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.Objects;

public class FlutterTapjoyPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static MethodChannel Channel;
    static Activity activity;
    TJPlacement placement;

    @Override
    public void onAttachedToEngine(@NonNull final FlutterPluginBinding flutterPluginBinding) {
        this.OnAttachedToEngine(flutterPluginBinding.getBinaryMessenger());
    }

    public static void registerWith(final Registrar registrar) {
        if (activity == null) activity = registrar.activity();
    }

    private void OnAttachedToEngine(final BinaryMessenger messenger) {
        if (FlutterTapjoyPlugin.Channel != null)
            return;
        FlutterTapjoyPlugin.Channel = new MethodChannel(messenger, "native");
        FlutterTapjoyPlugin.Channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull final Result result) {
        try {
            switch (call.method) {
                case "setEarnedCurrencyListener":
                    Tapjoy.setEarnedCurrencyListener(new TJEarnedCurrencyListener() {
                            @Override
                            public void onEarnedCurrency(String s, final int i) {
                                try {
                                    FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                        @Override
                                        public void run() {
                                            Channel.invokeMethod("onEarnedCurrency", i);
                                        }
                                    });
                                } catch (final Exception e) {
                                    Log.e("Tapjoy", "Error " + e.toString());
                                }

                            }
                        });
                        break;
                        case "setDebugEnabled":
                            boolean isDebug;
                            if (call.argument("isDebug") != null) {
                                isDebug = call.argument("isDebug");
                            } else {
                                result.error("no_debug", "a null value for debug was provided", null);
                                return;
                            }
                            Tapjoy.setDebugEnabled(isDebug);
                            break;
                        case "setUserConsent":
                            String consent = null;
                            if (call.argument("consent") != null) {
                                consent = call.argument("consent");
                            } else {
                                result.error("no_consent", "a null consent string was provided", null);
                                return;
                            }
                            Tapjoy.setUserConsent(consent);
                            break;
                        case "connect":
                            String api_token = null;
                            if (call.argument("api_token") != null) {
                                api_token = call.argument("api_token");
                            } else {
                                result.error("no_api_token", "a null api token was provided", null);
                                return;
                            }
                            final Hashtable < String, Object > connectFlags = new Hashtable < > (); Tapjoy.connect(activity.getApplicationContext(), api_token, connectFlags, new TJConnectListener() {
                                @Override
                                public void onConnectSuccess() {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onConnectSuccess", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override
                                public void onConnectFailure() {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onConnectFailure", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }
                            });
                            break;
                        case "getPlacement":
                            String placementName = null;
                            if (call.argument("placementName") != null) {
                                placementName = call.argument("placementName");
                            } else {
                                result.error("no_placement_name", "a null placement name was provided", null);
                                return;
                            }
                            Tapjoy.setActivity(activity); placement = Tapjoy.getPlacement(placementName, new TJPlacementListener() {
                                @Override
                                public void onRequestSuccess(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onRequestSuccess", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }
                                @Override
                                public void onRequestFailure(final TJPlacement tjPlacement, final TJError tjError) {
                                    final String error = tjError.message;
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onRequestFailure", error);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override
                                public void onContentReady(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentReady", true);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }



                                @Override public void onContentShow(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentShow", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }
                                }

                                @Override public void onContentDismiss(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onContentDismiss", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override public void onRewardRequest(final TJPlacement tjPlacement, final TJActionRequest tjActionRequest, final String s, final int rew) {
 
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {

                                                Channel.invokeMethod("onReward", rew);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }

                                @Override public void onPurchaseRequest(final TJPlacement tjPlacement, final TJActionRequest tjActionRequest, final String s) {

                                }

                                @Override public void onClick(final TJPlacement tjPlacement) {
                                    try {
                                        FlutterTapjoyPlugin.activity.runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                Channel.invokeMethod("onClick", null);
                                            }
                                        });
                                    } catch (final Exception e) {
                                        Log.e("Tapjoy", "Error " + e.toString());
                                    }

                                }
                            });
                            break;
                        case "requestContent":
                            if (Tapjoy.isConnected()) {
                                placement.requestContent();
                            } else {
                                Log.e("Tapjoy", "Tapjoy SDK must finish connecting before requesting content.");
                            }
                            break;
                         case "showContent":
                
                            if (placement.isContentReady()) {
                                placement.showContent();
                            } else {
                                Log.e("Tapjoy", "Tapjoy SDK content not downloaded.");
                            }

                            break;
                    }
                    result.success(Boolean.TRUE);
            } catch (final Exception e) {
                Log.e("Tapjoy", "Error " + e.toString());
            }
        }

        @Override
        public void onDetachedFromEngine(@NonNull final FlutterPluginBinding binding) {}

        @Override
        public void onAttachedToActivity(final ActivityPluginBinding binding) {
            FlutterTapjoyPlugin.activity = binding.getActivity();
        }

        @Override
        public void onDetachedFromActivityForConfigChanges() {

        }

        @Override
        public void onReattachedToActivityForConfigChanges(final ActivityPluginBinding binding) {
            FlutterTapjoyPlugin.activity = binding.getActivity();
        }

        @Override
        public void onDetachedFromActivity() {

        }

    }
